Initialize Playwright
pw_init.RdThis function initializes a Playwright project in the tests folder.
Usage
pw_init(
where = golem::get_golem_wd(),
create_playwright_version = "1.17.138",
create_playwright_args = c("--no-examples", "--quiet")
)pw_init.RdThis function initializes a Playwright project in the tests folder.
pw_init(
where = golem::get_golem_wd(),
create_playwright_version = "1.17.138",
create_playwright_args = c("--no-examples", "--quiet")
)