Add a new Playwright test
pw_use_test.RdThis function adds a new Playwright test file to the tests/playwright/tests directory.
Usage
pw_use_test(name, where = golem::get_golem_wd())pw_use_test.RdThis function adds a new Playwright test file to the tests/playwright/tests directory.
pw_use_test(name, where = golem::get_golem_wd())